/*
 * Copyright 2008 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.system.adapters;

import org.wamblee.system.container.Container;
import org.wamblee.system.core.Component;
import org.wamblee.system.core.ProvidedInterface;
import org.wamblee.system.core.RequiredInterface;

public class DefaultContainer extends Container {

    public DefaultContainer(String aName) {
        super(aName);
    }

    @Override
    public DefaultContainer addComponent(Component aComponent) {
        super.addComponent(aComponent);
        return this;
    }
    
    public DefaultContainer addComponent(String aName, ClassConfiguration aConfiguration) {
        return addComponent(new ClassAdapter(aName, aConfiguration));
    }

    public DefaultContainer addComponent(String aName, Object aObject, ObjectConfiguration aConfiguration) {
        if ( !aConfiguration.appliesTo(aObject) ) { 
            throw new IllegalArgumentException("Configuration '" + aConfiguration + "' does nto applu to '"  + 
                    aObject + "'");
        }
        return addComponent(new ObjectAdapter(aName, aObject, aConfiguration));
    }

    
    @Override
    public DefaultContainer addRequiredInterface(RequiredInterface aRequired) {
        super.addRequiredInterface(aRequired);
        return this;
    }

    @Override
    public DefaultContainer addProvidedInterface(ProvidedInterface aProvided) {
        super.addProvidedInterface(aProvided);
        return this;
    }

}
