/*
 * Copyright 2008 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.system.adapters;

import org.wamblee.system.core.AbstractComponent;
import org.wamblee.system.core.DefaultProvidedInterface;
import org.wamblee.system.core.ProvidedInterface;
import org.wamblee.system.core.RequiredInterface;
import org.wamblee.system.core.Scope;

/**
 * An adapter class that adapts an existing object to a component. 
 *  
 * @author Erik Brakkee
 */
public class ObjectAdapter extends AbstractComponent<Object> {

	private ObjectConfiguration _objectConfig;
	private Object _object; 

	public ObjectAdapter(String aName, Object aObject, ObjectConfiguration aObjectConfig) {
		super(aName, 
				new ProvidedInterface[] { new DefaultProvidedInterface(aName, aObject.getClass()) },
				aObjectConfig.getRequiredInterfaces().toArray(new RequiredInterface[0]));
		_objectConfig = aObjectConfig;
		_object = aObject; 
	}
	
	@Override
	protected Object doStart(Scope aScope) {

	    _objectConfig.inject(aScope, _object);
	    
	    for (ProvidedInterface provided: getProvidedInterfaces()) { 
	    	addInterface(provided, _object, aScope); 
	    }
	    
	    return _object; 
	}
	
	@Override
	protected void doStop(Object aRuntime) {
		// Empty. 
	}
}
