/*
 * Copyright 2008 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.system.core;

/**
 * Represents a provided interface together with its implementation. 
 * 
 * @author Erik Brakkee
 */
class ProvidedInterfaceImplementation {

	private ProvidedInterface _provided; 
	private Object _implementation; 
	
	/**
	 * Constructs the object. 
	 * @param aProvided Provided interface. 
	 * @param aImplementation Implementation. 
	 */
	public ProvidedInterfaceImplementation(ProvidedInterface aProvided, Object aImplementation) { 
		_provided = aProvided; 
		_implementation = aImplementation; 
	}

	/**
	 * @return The provided interface.
	 */
	public ProvidedInterface getProvided() {
		return _provided;
	}
	
	/**
	 * @param <T> Expected type of the implementation. 
	 * @param aType Type of the implementation. 
	 * @return Implementation. 
	 */
	public <T> T getImplementation(Class<T> aType) {
		return (T)_implementation;
	}
}
