/*
 * Copyright 2007 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.system.core;

public interface RequiredInterface extends NamedInterface {
	
	/**
	 * @return True iff the required interface is optional. 
	 */
	boolean isOptional(); 
	
	
	/**
	 * Checks if the service is provided by a given provided interface. 
	 * @param aInterface Provided interface. 
	 * @return
	 */
	boolean implementedBy(ProvidedInterface aInterface);
	
	/**
	 * Sets the provider of this interface. 
	 * @param aProvider Provider. 
	 */
	void setProvider(ProvidedInterface aProvider);
	
	/**
	 * Gets the provider interface. 
	 * @return Provider or null if not set. 
	 */
	ProvidedInterface getProvider();
	
	/**
	 * Determines if the requirements of the current interface are at least those
	 * of the given required interface. 
	 */
	boolean covers(RequiredInterface aInterface); 
}
