/*
 * Copyright 2008 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.system.graph;

/**
 * Represents an application-independent edge of a graph. 
 * Applications might choose to implement the Edge interface
 * directly. 
 * 
 * @author Erik Brakkee
 */
public class DefaultEdge implements Edge {
    
    private Node _from; 
    private Node _to; 
    
    public DefaultEdge(Node aFrom, Node aTo) { 
        _from = aFrom;
        _to = aTo; 
    }

    @Override
    public Node getFrom() {
        return _from;
    }

    @Override
    public Node getTo() {
        return _to; 
    }
    
    @Override
    public String toString() {
        return "Edge(" + _from.getName() + ", " + _to.getName() + ")";
    }

}
