/*
 * Copyright 2008 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.system.graph;

/**
 * Default application-independent node. Specific applications of the graph might
 * implement the Node interface directly.  
 * @author Erik Brakkee
 *
 */
public class DefaultNode implements Node {
    
    private String _name; 
    
    /**
     * Constructs the node. 
     * @param aName Node name. 
     */
    public DefaultNode(String aName) { 
        _name = aName; 
    }

    /**
     * Returns the node name. 
     */
    @Override
    public String getName() {
        return _name;
    }

    @Override
    public boolean equals(Object aObj) {
        if ( !(aObj instanceof Node)) { 
            return false; 
        }
        Node node = (Node)aObj;
        return _name.equals(node.getName());
    }
    
    @Override
    public int hashCode() {
        return _name.hashCode();
    }
}
