/*
 * Copyright 2008 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.system.graph.component;

import java.util.ArrayList;
import java.util.List;

import org.wamblee.system.core.SystemAssemblyException;
import org.wamblee.system.graph.Edge;
import org.wamblee.system.graph.Graph;
import org.wamblee.system.graph.Node;
import org.wamblee.system.graph.Visitor;

/**
 * Checks whether the given component graph can be started in component
 * order without any missing dependencies. 
 * @author Erik Brakkee
 *
 */
public class CheckStartupDependenciesVisitor implements Visitor {
    
    private Graph _graph; 
    private List<Node> _available; 

    /**
     * Constructs the visitor. 
     * @param aGraph Graph. 
     */
    public CheckStartupDependenciesVisitor(Graph aGraph) { 
        _graph = aGraph; 
        _available = new ArrayList<Node>();
    }

    @Override
    public void visitEdge(Edge aEdge) {
        // Empty
    }

    @Override
    public void visitNode(Node aNode) {
        List<Edge> edges = _graph.findOutgoing(aNode);
        
        // check dependencies.
        for (Edge edge: edges) { 
            Node dep = edge.getTo();
            if ( !_available.contains(dep)) { 
                throw new SystemAssemblyException(aNode + ": required dependency '" + dep + "' was not started");
            }
        }
        
        _available.add(aNode);
    }

}
