/*
 * Copyright 2008 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.system.graph.component;

import org.wamblee.system.core.Component;
import org.wamblee.system.core.ProvidedInterface;
import org.wamblee.system.graph.Node;

/**
 * Provided interface node. 
 * @author Erik Brakkee
 */
public class ProvidedInterfaceNode implements Node {
    
    private Component _component; 
    private ProvidedInterface _provided;
    
    public ProvidedInterfaceNode(Component aComponent, ProvidedInterface aProvided) {
        _component = aComponent; 
        _provided = aProvided; 
    }

    @Override
    public String getName() {
        return _component.getQualifiedName() + ":" + _provided.getName(); 
    }

    public ProvidedInterface getProvided() {
        return _provided;
    }
    
    public Component getComponent() {
        return _component;
    }
    
    @Override
    public String toString() {
        return _component.getQualifiedName() + ":" + _provided; 
    }
}
