/**
 * <h1>Graph component package </h1>
 * 
 * The graph component package provides the representation of a number of 
 * components {@link Component} 
 * their required and provided interfaces ({@link RequiredInterface} and 
 * {@link ProvidedInterface}), and how these are connected together.
 * 
 * This package provides the bridge between the component model and the 
 * representation of the components and their connections in a graph. 
 * The component package provides various algorithms, filters, and 
 * validations that are required for the implementation of a container. 
 * 
 * The main abstractions are: 
 * <ul>
 *   <li> {@link ComponentGraph}: A graph of components. This provides the logic
 *   for creating a graph based on components. </li>
 *   <li> {@link ComponentNode}: A node representing a component. </li>
 *   <li> {@link RequiredInterfaceNode}: A node representing a required interface of a component. </li>
 *   <li> {@link ProvidedInterfaceNode}: A node repesenting a provided interface of a component. </li>
 *   <li> {@link ExternalRequiredInterfaceNode}: A node representing a required interface of a container </li>
 *   <li> {@link ExternalProvidedInterfaceNode}: A node representing a provided interface of a container </li>  
 * </ul> 
 *
 */
package org.wamblee.system.graph.component;

import org.wamblee.system.core.Component;
import org.wamblee.system.core.ProvidedInterface;
import org.wamblee.system.core.RequiredInterface;

